Python: module mlock

mlock | index /tmp/makerelease-pwman-python.6KILBD5b/pwman-python-2.6/libpwman/mlock.py

`#
# mlock support
#
# Copyright 2019-2020 Michael Buesch <m@bues.ch>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#`

Modules
`` |  |
os | platform | sys |

Classes
`` |  | builtins.object MLockWrapper
class MLockWrapper(builtins.object)
`` | `OS mlock wrapper.`
| Methods defined here: __init__(self) `Initialize self. See help(type(self)) for accurate signature.` Class methods defined here: get() from builtins.type mlockall(flags) from builtins.type munlockall() from builtins.type Data descriptors defined here: __dict__ `dictionary for instance variables (if defined)` __weakref__ `list of weak references to the object (if defined)` Data and other attributes defined here: MCL_CURRENT = 1 MCL_FUTURE = 2 MCL_ONFAULT = 4 singleton = None

Data
`` |  | __all__ = ['MLockWrapper']